@@ -4,7 +4,8 @@ use 5.34.0;
 use strict;
 use warnings;
 
-use experimental 'try';
+use feature 'try';
+no warnings 'experimental::try';
 
 use Moose;
 use namespace::autoclean;
@@ -18,7 +19,7 @@ use XML::Feed;
 
 use Perlanet::Types;
 
-our $VERSION = '3.3.3';
+our $VERSION = '3.3.4';
 
 with 'MooseX::Traits';
 
